==> e107-0.7.20.tbz: www/e107/e107_plugins/featurebox/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/featurebox/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("FBLAN_01", "Feature Box");
define("FBLAN_02", "This plugin allows you to display a box above your news items with features / whatever you like in it. The messages can either be revolved randomly or dynamically faded.");
define("FBLAN_03", "Configure feature box");
define("FBLAN_04", "Feature Box plugin has been successfully installed. To add messages and configure, return to the main admin page and click on the feature box icon in the plugin section.");
define("FBLAN_05", "No feature box messages defined yet");
define("FBLAN_06", "Existing Feature Box Messages");
define("FBLAN_07", "Title / Caption");
define("FBLAN_08", "Message text");
define("FBLAN_09", "Visibility of message");
define("FBLAN_10", "Create Feature Box Message");
define("FBLAN_11", "Update Feature Box Message");
define("FBLAN_12", "Mode");
define("FBLAN_13", "Randomly revolve messages");
define("FBLAN_14", "Show this message only");
define("FBLAN_15", "Message added to database.");
define("FBLAN_16", "Message updated in database.");
define("FBLAN_17", "Field(s) left blank");
define("FBLAN_18", "Feature Box Message deleted");
define("FBLAN_19", "Options");
define("FBLAN_20", "Edit");
define("FBLAN_21", "Delete");
define("FBLAN_22", "Render type");
define("FBLAN_23", "In theme box");
define("FBLAN_24", "Plain");
define("FBLAN_25", "Template");
define("FBLAN_26", "you can use a different template for each message, add templates to e107_plugins/featurebox/templates/ folder");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/featurebox/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/featurebox/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("FBLAN_01", "Feature Box");
define("FBLAN_02", "This plugin allows you to display a box above your news items with features / whatever you like in it. The messages can either be revolved randomly or dynamically faded.");
define("FBLAN_03", "Configure feature box");
define("FBLAN_04", "Feature Box plugin has been successfully installed. To add messages and configure, return to the main admin page and click on the feature box icon in the plugin section.");
define("FBLAN_05", "No feature box messages defined yet");
define("FBLAN_06", "Existing Feature Box Messages");
define("FBLAN_07", "Title / Caption");
define("FBLAN_08", "Message text");
define("FBLAN_09", "Visibility of message");
define("FBLAN_10", "Create Feature Box Message");
define("FBLAN_11", "Update Feature Box Message");
define("FBLAN_12", "Mode");
define("FBLAN_13", "Randomly revolve messages");
define("FBLAN_14", "Show this message only");
define("FBLAN_15", "Message added to database.");
define("FBLAN_16", "Message updated in database.");
define("FBLAN_17", "Field(s) left blank");
define("FBLAN_18", "Feature Box Message deleted");
define("FBLAN_19", "Options");
define("FBLAN_20", "Edit");
define("FBLAN_21", "Delete");
define("FBLAN_22", "Render type");
define("FBLAN_23", "In theme box");
define("FBLAN_24", "Plain");
define("FBLAN_25", "Template");
define("FBLAN_26", "you can use a different template for each message, add templates to e107_plugins/featurebox/templates/ folder");

?>
